@@ -15,7 +15,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include "fileio.h"
 #include "misc.h"
 #ifdef G_OS_WIN32
 # include <shlobj.h>
@@ -499,7 +498,7 @@ misc_spec_locale (const gchar *prgname)
   gchar *tmp;
 # endif /* G_OS_WIN32 */
 
-  path = fileio_get_full_path (prgname);
+  path = g_path_get_absolute (prgname, NULL);
   dirname = g_path_get_dirname (path);
   g_free (path);
   locale = g_build_filename (dirname, "locale", NULL);
