@@ -31,16 +31,12 @@
 #include "root.h"
 #include "sigmain.h"
 #include "version.h"
-#include "misc/fileio.h"
 #include "misc/misc.h"
 #include "orz/orzcharlist.h"
 #include "orz/orzcharset.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 #include "orz/orzpref.h"
-#ifdef G_OS_WIN32
-# include <gdk/gdkwin32.h>
-#endif /* G_OS_WIN32 */
 
 
 /******************************************************************************
@@ -103,7 +99,7 @@ command_open (GtkWidget *widget,
       gchar *path;
 
       g_free (open_path);
-      path = fileio_get_full_path (file);
+      path = g_path_get_absolute (file, NULL);
       open_path = g_path_get_dirname (path);
       g_free (path);
       file_open_edit (file);
@@ -467,7 +463,7 @@ command_saveas (GtkWidget *widget,
           gchar *path;
 
           g_free (save_path);
-          path = fileio_get_full_path (file);
+          path = g_path_get_absolute (file, NULL);
           save_path = g_path_get_dirname (path);
           g_free (path);
           /* ja:キャラクターセット */
