@@ -18,7 +18,6 @@
 #include "edit.h"
 #include "general.h"
 #include "mm_list.h"
-#include "misc/fileio.h"
 #include "misc/misc.h"
 #include "orz/orzcharset.h"
 #include "orz/orzmdi.h"
@@ -61,7 +60,7 @@ edit_dialog_clicked (GtkWidget  *widget,
       gchar *dir, *path;
 
       dir = g_path_get_dirname (file);
-      path = fileio_get_full_path (dir);
+      path = g_path_get_absolute (dir, NULL);
       g_free (dir);
       if (g_file_test (path, G_FILE_TEST_EXISTS))
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
@@ -734,7 +733,7 @@ edit_dialog (MmaidWindow *mmaid)
 
           file = g_filename_from_utf8 (gtk_entry_get_text
                             (GTK_ENTRY (editdlg.entry)), -1, NULL, NULL, NULL);
-          tmp = fileio_get_full_path (file);
+          tmp = g_path_get_absolute (file, NULL);
           g_free (file);
           file = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
           g_free (tmp);
