@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -151,15 +151,14 @@ export_dialog (const gchar *def_charset)
   gtk_box_pack_start (GTK_BOX (vbox), expdlg.spin, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), expdlg.label, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (expdlg.dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), expdlg.charset, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (expdlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_show_all (vbox);
