@@ -270,7 +270,7 @@ file_open_id3tag (const gchar *file,
   if (!fio)
     return NULL;
   id3tag = g_malloc0 (sizeof (ID3Tag));
-  tmp = fileio_get_full_path (file);
+  tmp = g_path_get_absolute (file, NULL);
   id3tag->file = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
   g_free (tmp);
   id3tag->track = -1;
@@ -553,7 +553,7 @@ file_open_db (const gchar *file,
     for (j = 0; j < 5; j++)
       g_free (mi_r[i].str[j]);
   /* ja:リストに追加 */
-  dir = fileio_get_full_path (file);
+  dir = g_path_get_absolute (file, NULL);
   tmp = g_path_get_dirname (dir);
   g_free (dir);
   dir = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
@@ -721,7 +721,7 @@ file_open_list (const gchar *file,
       while (gtk_events_pending ())
         gtk_main_iteration ();
       id3tag = g_malloc0 (sizeof (ID3Tag));
-      id3tag->file  = fileio_get_full_path (glist->data);
+      id3tag->file  = g_path_get_absolute (glist->data, NULL);
       id3tag->track = -1;
       mm_list_append (MM_LIST (mmaid->list), id3tag);
       g_free (glist->data);
@@ -766,7 +766,7 @@ file_open_edit (const gchar *file)
     }
   else
     {
-      filename = fileio_get_full_path (file);
+      filename = g_path_get_absolute (file, NULL);
       mmaid->charset = g_strdup (charset_list);
       mmaid->filetype = file_is_type (file);
       if (mmaid->filetype == FILE_TYPE_LIST)
@@ -969,7 +969,7 @@ file_save_db (const gchar *file,
   gtk_grab_add (dialog);
   /* ja:変数 */
   count = MIN (mm_list_length (MM_LIST (mmaid->list)), 10240);
-  root = fileio_get_full_path (file);
+  root = g_path_get_absolute (file, NULL);
   tmp = g_path_get_dirname (root);
   g_free (root);
   root = g_strconcat (tmp, G_DIR_SEPARATOR_S, NULL);
@@ -1241,7 +1241,7 @@ file_save_list (const gchar    *file,
 
                   file = g_filename_from_utf8 (id3tag->file, -1,
                                                             NULL, NULL, NULL);
-                  relative = fileio_get_relative_path (file, root);
+                  relative = g_path_get_relative (file, root);
                   g_free (file);
                   element = g_filename_to_utf8 (relative, -1,
                                                             NULL, NULL, NULL);
