@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -412,8 +412,8 @@ genre_dialog (void)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   /* ja:フレームとボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (gnrdlg.dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_box_pack_start (GTK_BOX (hbox), gnrdlg.button0, FALSE, FALSE, 0);
@@ -421,7 +421,6 @@ genre_dialog (void)
   gtk_box_pack_start (GTK_BOX (hbox), gnrdlg.button2, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), gnrdlg.button3, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (gnrdlg.dialog)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_set_sensitive (gnrdlg.button0, FALSE);
