@@ -19,11 +19,7 @@
 #define __MMAID_H__
 
 
-#include "misc/gcommon.h"
-#ifdef G_OS_WIN32
-# include <tchar.h>
-# include <windows.h>
-#endif /* G_OS_WIN32 */
+#include "gcommon/gcommon.h"
 
 
 G_BEGIN_DECLS
