@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 #include "general.h"
 #include "mm_list.h"
 #include "root.h"
-#include "misc/fileio.h"
 #include "misc/misc.h"
 #include "orz/orzmdi.h"
 
@@ -160,7 +159,7 @@ root_dialog_changed (GtkWidget  *widget,
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   replace = g_filename_from_utf8 (gtk_entry_get_text
                             (GTK_ENTRY (rtdlg->entry)), -1, NULL, NULL, NULL);
-  tmp = fileio_get_full_path (replace);
+  tmp = g_path_get_absolute (replace, NULL);
   g_free (replace);
   replace = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
   g_free (tmp);
@@ -376,7 +375,7 @@ root_dialog (MmaidWindow *mmaid)
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
       replace = g_filename_from_utf8 (gtk_entry_get_text
                             (GTK_ENTRY (rtdlg.entry)), -1, NULL, NULL, NULL);
-      tmp = fileio_get_full_path (replace);
+      tmp = g_path_get_absolute (replace, NULL);
       g_free (replace);
       replace = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
       g_free (tmp);
